@@ -57,6 +57,10 @@ def _register_class(resource_type, resource_class):
     resources.global_env().register_class(resource_type, resource_class)
 
 
+# Attention developers about to move/delete this: STOP IT!!!
+UpdateReplace = exception.UpdateReplace
+
+
 @six.python_2_unicode_compatible
 class Resource(object):
     ACTIONS = (
@@ -370,14 +374,18 @@ class Resource(object):
                             % {'a': action, 'h': hook})
             self.trigger_hook(hook)
             LOG.info(_LI('Reached hook on %s'), six.text_type(self))
-        while self.has_hook(hook) and self.status != self.FAILED:
-            try:
-                yield
-            except Exception:
-                self.clear_hook(hook)
-                self._add_event(
-                    self.action, self.status,
-                    "Failure occurred while waiting.")
+
+            while self.has_hook(hook) and self.status != self.FAILED:
+                try:
+                    yield
+                except BaseException as exc:
+                    self.clear_hook(hook)
+                    self._add_event(
+                        self.action, self.status,
+                        "Failure occurred while waiting.")
+                    if (isinstance(exc, AssertionError) or
+                            not isinstance(exc, Exception)):
+                        raise
 
     def has_nested(self):
         # common resources have not nested, StackResource overrides it
@@ -418,9 +426,14 @@ class Resource(object):
         """
         if self.type() == resource_type:
             return True
-        ri = self.stack.env.get_resource_info(self.type(),
-                                              self.name)
-        return ri is not None and ri.name == resource_type
+
+        try:
+            ri = self.stack.env.get_resource_info(self.type(),
+                                                  self.name)
+        except exception.ResourceTypeNotFound:
+            return False
+        else:
+            return ri.name == resource_type
 
     def implementation_signature(self):
         """Return a tuple defining the implementation.
@@ -488,10 +501,24 @@ class Resource(object):
             if psv.immutable():
                 immutable_set.add(psk)
 
+        def prop_changed(key):
+            try:
+                before = before_props.get(key)
+            except (TypeError, ValueError) as exc:
+                # We shouldn't get here usually, but there is a known issue
+                # with template resources and new parameters in non-convergence
+                # stacks (see bug 1543685). The error should be harmless
+                # because we're on the before properties, which have presumably
+                # already been validated.
+                LOG.warning(_LW('Ignoring error in old property value '
+                                '%(prop_name)s: %(msg)s'),
+                            {'prop_name': key, 'msg': six.text_type(exc)})
+                return True
+
+            return before != after_props.get(key)
+
         # Create a set of keys which differ (or are missing/added)
-        changed_properties_set = set(k for k in after_props
-                                     if before_props.get(k) !=
-                                     after_props.get(k))
+        changed_properties_set = set(k for k in after_props if prop_changed(k))
 
         # Create a list of updated properties offending property immutability
         update_replace_forbidden = [k for k in changed_properties_set
@@ -504,7 +531,7 @@ class Resource(object):
             raise exception.NotSupported(feature=mesg)
 
         if not changed_properties_set.issubset(update_allowed_set):
-            raise exception.UpdateReplace(self.name)
+            raise UpdateReplace(self.name)
 
         return dict((k, after_props.get(k)) for k in changed_properties_set)
 
@@ -524,11 +551,31 @@ class Resource(object):
     def dep_attrs(self, resource_name):
         return self.t.dep_attrs(resource_name)
 
-    def add_dependencies(self, deps):
+    def add_explicit_dependencies(self, deps):
+        """Add all dependencies explicitly specified in the template.
+
+        The deps parameter is a Dependencies object to which dependency pairs
+        are added.
+        """
         for dep in self.t.dependencies(self.stack):
             deps += (self, dep)
         deps += (self, None)
 
+    def add_dependencies(self, deps):
+        """Add implicit dependencies specific to the resource type.
+
+        Some resource types may have implicit dependencies on other resources
+        in the same stack that are not linked by a property value (that would
+        be set using get_resource or get_attr for example, thus creating an
+        explicit dependency). Such dependencies are opaque to the user and
+        should be avoided wherever possible, however in some circumstances they
+        are required due to magic in the underlying API.
+
+        The deps parameter is a Dependencies object to which dependency pairs
+        may be added.
+        """
+        return
+
     def required_by(self):
         """List of resources' names which require the resource as dependency.
 
@@ -848,11 +895,11 @@ class Resource(object):
     def _needs_update(self, after, before, after_props, before_props,
                       prev_resource, check_init_complete=True):
         if self.status == self.FAILED:
-            raise exception.UpdateReplace(self)
+            raise UpdateReplace(self)
 
         if check_init_complete and \
                 (self.action == self.INIT and self.status == self.COMPLETE):
-            raise exception.UpdateReplace(self)
+            raise UpdateReplace(self)
 
         if prev_resource is not None:
             cur_class_def, cur_ver = self.implementation_signature()
@@ -919,6 +966,7 @@ class Resource(object):
         after_props = after.properties(self.properties_schema,
                                        self.context)
         self.translate_properties(after_props)
+        self.translate_properties(before_props)
 
         yield self._break_if_required(
             self.UPDATE, environment.HOOK_PRE_UPDATE)
@@ -938,7 +986,7 @@ class Resource(object):
             LOG.info(_LI('updating %s'), six.text_type(self))
 
             self.updated_time = datetime.utcnow()
-            with self._action_recorder(action, exception.UpdateReplace):
+            with self._action_recorder(action, UpdateReplace):
                 after_props.validate()
                 tmpl_diff = self.update_template_diff(function.resolve(after),
                                                       before)
@@ -951,7 +999,7 @@ class Resource(object):
                 self.t = after
                 self.reparse()
                 self._update_stored_properties()
-        except exception.UpdateReplace as ex:
+        except UpdateReplace as ex:
             # catch all UpdateReplace expections
             try:
                 if (self.stack.action == 'ROLLBACK' and
@@ -1646,6 +1694,9 @@ class Resource(object):
     def signal(self, details=None, need_check=True):
         """Signal the resource.
 
+        Returns True if the metadata for all resources in the stack needs to
+        be regenerated as a result of the signal, False if it should not be.
+
         Subclasses should provide a handle_signal() method to implement the
         signal. The base-class raise an exception if no handler is implemented.
         """
@@ -1654,12 +1705,13 @@ class Resource(object):
             self._signal_check_hook(details)
         if details and 'unset_hook' in details:
             self._unset_hook(details)
-            return
+            return False
         self._handle_signal(details)
+        return self.signal_needs_metadata_updates
 
-    def handle_update(self, json_snippet=None, tmpl_diff=None, prop_diff=None):
+    def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         if prop_diff:
-            raise exception.UpdateReplace(self.name)
+            raise UpdateReplace(self.name)
 
     def metadata_update(self, new_metadata=None):
         """No-op for resources which don't explicitly override this method."""
