@@ -16,6 +16,7 @@ import copy
 import itertools
 
 import six
+import six.moves
 
 from heat.common import exception
 from heat.common import grouputils
@@ -281,11 +282,7 @@ class ResourceGroup(stack_resource.StackResource):
         val_templ = template.Template(test_tmpl)
         res_def = val_templ.resource_definitions(self.stack)["0"]
         # make sure we can resolve the nested resource type
-        try:
-            self.stack.env.get_class(res_def.resource_type)
-        except exception.TemplateNotFound:
-            # its a template resource
-            pass
+        self.stack.env.get_class_to_instantiate(res_def.resource_type)
 
         try:
             name = "%s-%s" % (self.stack.name, self.name)
@@ -497,8 +494,6 @@ class ResourceGroup(stack_resource.StackResource):
         valid_resources = [(n, d) for n, d in self._get_resources()
                            if n not in name_blacklist]
 
-        num_creating = max(total_capacity - len(valid_resources), 0)
-        new_names = iter(names[total_capacity - num_creating:])
         targ_cap = self.get_size()
 
         def replace_priority(res_item):
@@ -518,6 +513,10 @@ class ResourceGroup(stack_resource.StackResource):
 
         old_resources = sorted(valid_resources, key=replace_priority)
 
+        existing_names = set(n for n, d in valid_resources)
+        new_names = six.moves.filterfalse(lambda n: n in existing_names,
+                                          names)
+
         res_def = self._build_resource_definition(include_all)
         resources = scale_template.member_definitions(old_resources, res_def,
                                                       total_capacity,
