@@ -31,6 +31,7 @@ class ServerNetworkMixin(object):
         net_id = network.get(self.NETWORK_ID)
         port = network.get(self.NETWORK_PORT)
         subnet = network.get(self.NETWORK_SUBNET)
+        fixed_ip = network.get(self.NETWORK_FIXED_IP)
 
         if (net_id is None and port is None
            and net_uuid is None and subnet is None):
@@ -64,6 +65,12 @@ class ServerNetworkMixin(object):
                           network=network[self.NETWORK_ID],
                           server=self.name))
 
+        # Nova doesn't allow specify ip and port at the same time
+        if fixed_ip and port:
+            raise exception.ResourcePropertyConflict(
+                "/".join([self.NETWORKS, self.NETWORK_FIXED_IP]),
+                "/".join([self.NETWORKS, self.NETWORK_PORT]))
+
     def _validate_belonging_subnet_to_net(self, network):
         if network.get(self.NETWORK_PORT) is None and self.is_using_neutron():
             net = self._get_network_id(network)
@@ -81,7 +88,8 @@ class ServerNetworkMixin(object):
                         'network': net}
                     raise exception.StackValidationFailed(message=msg)
 
-    def _create_internal_port(self, net_data, net_number):
+    def _create_internal_port(self, net_data, net_number,
+                              security_groups=None):
         name = _('%(server)s-port-%(number)s') % {'server': self.name,
                                                   'number': net_number}
 
@@ -98,6 +106,11 @@ class ServerNetworkMixin(object):
         if body:
             kwargs.update({'fixed_ips': [body]})
 
+        if security_groups:
+            sec_uuids = self.client_plugin(
+                'neutron').get_secgroup_uuids(security_groups)
+            kwargs['security_groups'] = sec_uuids
+
         port = self.client('neutron').create_port({'port': kwargs})['port']
 
         # Store ids (used for floating_ip association, updating, etc.)
@@ -174,7 +187,7 @@ class ServerNetworkMixin(object):
         for port_id in new_ports:
             self._data_update_ports(port_id, 'add', port_type='external_ports')
 
-    def _build_nics(self, networks):
+    def _build_nics(self, networks, security_groups=None):
         if not networks:
             return None
 
@@ -183,16 +196,20 @@ class ServerNetworkMixin(object):
         for idx, net in enumerate(networks):
             self._validate_belonging_subnet_to_net(net)
             nic_info = {'net-id': self._get_network_id(net)}
-            if net.get(self.NETWORK_FIXED_IP):
-                ip = net[self.NETWORK_FIXED_IP]
-                if netutils.is_valid_ipv6(ip):
-                    nic_info['v6-fixed-ip'] = ip
-                else:
-                    nic_info['v4-fixed-ip'] = ip
             if net.get(self.NETWORK_PORT):
                 nic_info['port-id'] = net[self.NETWORK_PORT]
             elif self.is_using_neutron() and net.get(self.NETWORK_SUBNET):
-                nic_info['port-id'] = self._create_internal_port(net, idx)
+                nic_info['port-id'] = self._create_internal_port(
+                    net, idx, security_groups)
+
+            # if nic_info including 'port-id', do not set ip for nic
+            if not nic_info.get('port-id'):
+                if net.get(self.NETWORK_FIXED_IP):
+                    ip = net[self.NETWORK_FIXED_IP]
+                    if netutils.is_valid_ipv6(ip):
+                        nic_info['v6-fixed-ip'] = ip
+                    else:
+                        nic_info['v4-fixed-ip'] = ip
             nics.append(nic_info)
         return nics
 
@@ -264,7 +281,8 @@ class ServerNetworkMixin(object):
             if net is not None:
                 net['port'] = props['port']
 
-    def calculate_networks(self, old_nets, new_nets, ifaces):
+    def calculate_networks(self, old_nets, new_nets, ifaces,
+                           security_groups=None):
         remove_ports = []
         add_nets = []
         attach_first_free_port = False
@@ -319,8 +337,8 @@ class ServerNetworkMixin(object):
             if net.get(self.NETWORK_PORT):
                 handler_kwargs['port_id'] = net.get(self.NETWORK_PORT)
             elif self.is_using_neutron() and net.get(self.NETWORK_SUBNET):
-                handler_kwargs['port_id'] = self._create_internal_port(net,
-                                                                       idx)
+                handler_kwargs['port_id'] = self._create_internal_port(
+                    net, idx, security_groups)
 
             add_nets.append(handler_kwargs)
 
