@@ -331,18 +331,31 @@ class EngineService(service.Service):
         self.stack_watch = service_stack_watch.StackWatch(
             self.thread_group_mgr)
 
-        # Create a periodic_watcher_task per-stack
-        admin_context = context.get_admin_context()
-        stacks = stack_object.Stack.get_all(
-            admin_context,
-            tenant_safe=False,
-            show_hidden=True)
-        for s in stacks:
-            self.stack_watch.start_watch_task(s.id, admin_context)
+        def create_watch_tasks():
+            while True:
+                try:
+                    # Create a periodic_watcher_task per-stack
+                    admin_context = context.get_admin_context()
+                    stacks = stack_object.Stack.get_all(
+                        admin_context,
+                        tenant_safe=False,
+                        show_hidden=True)
+                    for s in stacks:
+                        self.stack_watch.start_watch_task(s.id, admin_context)
+                    LOG.info(_LI("Watch tasks created"))
+                    return
+                except Exception as e:
+                    LOG.error(_LE("Watch task creation attempt failed, %s"), e)
+                    eventlet.sleep(5)
+
+        if self.manage_thread_grp is None:
+            self.manage_thread_grp = threadgroup.ThreadGroup()
+        self.manage_thread_grp.add_thread(create_watch_tasks)
 
     def start(self):
         self.engine_id = stack_lock.StackLock.generate_engine_id()
-        self.thread_group_mgr = ThreadGroupManager()
+        if self.thread_group_mgr is None:
+            self.thread_group_mgr = ThreadGroupManager()
         self.listener = EngineListener(self.host, self.engine_id,
                                        self.thread_group_mgr)
         LOG.debug("Starting listener for engine %s" % self.engine_id)
@@ -368,7 +381,8 @@ class EngineService(service.Service):
             version=self.RPC_API_VERSION)
 
         self.service_manage_cleanup()
-        self.manage_thread_grp = threadgroup.ThreadGroup()
+        if self.manage_thread_grp is None:
+            self.manage_thread_grp = threadgroup.ThreadGroup()
         self.manage_thread_grp.add_timer(cfg.CONF.periodic_interval,
                                          self.service_manage_report)
         self.manage_thread_grp.add_thread(self.reset_stack_status)
@@ -377,6 +391,8 @@ class EngineService(service.Service):
 
     def _stop_rpc_server(self):
         # Stop rpc connection at first for preventing new requests
+        if self._rpc_server is None:
+            return
         LOG.debug("Attempting to stop engine service...")
         try:
             self._rpc_server.stop()
@@ -393,20 +409,21 @@ class EngineService(service.Service):
             self.worker_service.stop()
 
         # Wait for all active threads to be finished
-        for stack_id in list(self.thread_group_mgr.groups.keys()):
-            # Ignore dummy service task
-            if stack_id == cfg.CONF.periodic_interval:
-                continue
-            LOG.info(_LI("Waiting stack %s processing to be finished"),
-                     stack_id)
-            # Stop threads gracefully
-            self.thread_group_mgr.stop(stack_id, True)
-            LOG.info(_LI("Stack %s processing was finished"), stack_id)
-
-        self.manage_thread_grp.stop()
-        ctxt = context.get_admin_context()
-        service_objects.Service.delete(ctxt, self.service_id)
-        LOG.info(_LI('Service %s is deleted'), self.service_id)
+        if self.thread_group_mgr:
+            for stack_id in list(self.thread_group_mgr.groups.keys()):
+                # Ignore dummy service task
+                if stack_id == cfg.CONF.periodic_interval:
+                    continue
+                LOG.info(_LI("Waiting stack %s processing to be finished"),
+                         stack_id)
+                # Stop threads gracefully
+                self.thread_group_mgr.stop(stack_id, True)
+                LOG.info(_LI("Stack %s processing was finished"), stack_id)
+        if self.manage_thread_grp:
+            self.manage_thread_grp.stop()
+            ctxt = context.get_admin_context()
+            service_objects.Service.delete(ctxt, self.service_id)
+            LOG.info(_LI('Service %s is deleted'), self.service_id)
 
         # Terminate the engine process
         LOG.info(_LI("All threads were gone, terminating engine"))
@@ -760,7 +777,7 @@ class EngineService(service.Service):
         # stack definition.  If PARAM_EXISTING is specified, we merge
         # any environment provided into the existing one and attempt
         # to use the existing stack template, if one is not provided.
-        if args.get(rpc_api.PARAM_EXISTING, None):
+        if args.get(rpc_api.PARAM_EXISTING):
             existing_env = current_stack.env.user_env_as_dict()
             existing_params = existing_env[env_fmt.PARAMETERS]
             clear_params = set(args.get(rpc_api.PARAM_CLEAR_PARAMETERS, []))
@@ -797,12 +814,14 @@ class EngineService(service.Service):
                               "stored")
                     msg = _('PATCH update to non-COMPLETE stack')
                     raise exception.NotSupported(feature=msg)
+            tmpl = templatem.Template(new_template, files=new_files,
+                                      env=new_env)
+            for key in list(new_env.params.keys()):
+                if key not in tmpl.param_schemata():
+                    new_env.params.pop(key)
         else:
-            new_env = environment.Environment(params)
-            new_files = files
-            new_template = template
-
-        tmpl = templatem.Template(new_template, files=new_files, env=new_env)
+            tmpl = templatem.Template(template, files=files,
+                                      env=environment.Environment(params))
 
         max_resources = cfg.CONF.max_resources_per_stack
         if max_resources != -1 and len(tmpl[tmpl.RESOURCES]) > max_resources:
@@ -1219,7 +1238,7 @@ class EngineService(service.Service):
             raise exception.InvalidGlobalResource(type_name=type_name)
 
         if resource_class.support_status.status == support.HIDDEN:
-            raise exception.NotSupported(type_name)
+            raise exception.NotSupported(feature=type_name)
 
         if not resource_class.is_service_available(cnxt):
             raise exception.ResourceTypeUnavailable(
@@ -1265,7 +1284,7 @@ class EngineService(service.Service):
             raise exception.InvalidGlobalResource(type_name=type_name)
         else:
             if resource_class.support_status.status == support.HIDDEN:
-                raise exception.NotSupported(type_name)
+                raise exception.NotSupported(feature=type_name)
             return resource_class.resource_to_template(type_name,
                                                        template_type)
 
@@ -1379,9 +1398,9 @@ class EngineService(service.Service):
 
         def _resource_signal(stack, rsrc, details, need_check):
             LOG.debug("signaling resource %s:%s" % (stack.name, rsrc.name))
-            rsrc.signal(details, need_check)
+            needs_metadata_updates = rsrc.signal(details, need_check)
 
-            if not rsrc.signal_needs_metadata_updates:
+            if not needs_metadata_updates:
                 return
 
             # Refresh the metadata for all other resources, since signals can
@@ -1811,8 +1830,6 @@ class EngineService(service.Service):
                 service_objects.Service.delete(cnxt, service_ref['id'])
 
     def set_stack_and_resource_to_failed(self, stack):
-        reason = ('Engine went down during stack %s' % stack.action)
-        stack.state_set(stack.action, stack.FAILED, six.text_type(reason))
         for name, rsrc in six.iteritems(stack.resources):
             if rsrc.status == rsrc.IN_PROGRESS:
                 status_reason = ('Engine went down '
@@ -1820,6 +1837,8 @@ class EngineService(service.Service):
                 rsrc.state_set(rsrc.action,
                                rsrc.FAILED,
                                six.text_type(status_reason))
+        reason = ('Engine went down during stack %s' % stack.action)
+        stack.state_set(stack.action, stack.FAILED, six.text_type(reason))
 
     def reset_stack_status(self):
         cnxt = context.get_admin_context()
