@@ -14,7 +14,7 @@
 
 import datetime
 
-from ceilometerclient.openstack.common.apiclient import client as cc
+import ceilometerclient
 import mox
 from oslo_utils import timeutils
 
@@ -635,7 +635,18 @@ class WatchRuleTest(common.HeatTestCase):
                                       stack_id=self.stack_id, rule=rule)
         self.wr.store()
 
-        self.patchobject(cc.HTTPClient, 'client_request')
+        # check version and mock accordingly
+        if ceilometerclient.__version__ >= '2.2':
+            from ceilometerclient.openstack.common.apiclient \
+                import client as cc
+            self.patchobject(cc.HTTPClient, 'client_request')
+        else:
+            # mock redirect_to_aodh_endpoint
+            from ceilometerclient import client as cc
+            from keystoneclient import exceptions
+            self.patchobject(cc.AuthPlugin, 'redirect_to_aodh_endpoint',
+                             side_effect=exceptions.EndpointNotFound)
+
         self.m.StubOutWithMock(self.wr.context.clients.client('ceilometer').
                                samples, 'create', True)
 
